Documentation
¶
Index ¶
- Constants
- type Action
- type Control
- type Device
- func (d *Device) Clear(ctx context.Context) error
- func (d *Device) Close()
- func (d *Device) Descriptor() string
- func (d *Device) ReadEvents(ctx context.Context) (<-chan Event, error)
- func (d *Device) SetBrightness(ctx context.Context, percent uint8) error
- func (d *Device) SetImage(ctx context.Context, display Control, img image.Image) error
- func (d *Device) SetImages(ctx context.Context, imgs [6]image.Image) error
- type DeviceInfo
- type Event
Constants ¶
const (
// ImageSize is the width and height of the quadratic images for the display buttons in pixels.
ImageSize = 64
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Device ¶
type Device struct {
// contains filtered or unexported fields
}
Device represents one Stream Controller SE that is connected via USB.
func Open ¶
Open the Stream Controller SE device with the given serial number. If the serial number is empty, the first available device is opened.
func (*Device) Close ¶
func (d *Device) Close()
Close the device and clean up the used system resources.
func (*Device) Descriptor ¶
func (*Device) ReadEvents ¶
ReadEvents returns a channel that provides the incoming events. This function starts a goroutine and must only be called once.
func (*Device) SetBrightness ¶
SetBrightness in percent (0-100).
type DeviceInfo ¶
func List ¶
func List() ([]DeviceInfo, error)
List the available Stream Controller SE devices with their serial number.
func (DeviceInfo) String ¶
func (i DeviceInfo) String() string
Click to show internal directories.
Click to hide internal directories.